from _pytest.tmpdir import TempdirFactory

from rasax.community.services import config_service


def test_get_runtime_config(tmpdir_factory: TempdirFactory):
    # make temp dir for tests
    temp_dir = tmpdir_factory.mktemp("runtime_config")

    # write runtime configs to files
    endpoints = """
    event_broker:
      url: localhost
      username: username
      password: password
      queue: queue
    """

    endpoints_path = str(temp_dir / "endpoints.yml")
    with open(endpoints_path, "w") as f:
        f.write(endpoints)

    credentials = """
    rasa:
        url: "http://localhost:5002/api"
    """

    credentials_path = str(temp_dir / "credentials.yml")
    with open(credentials_path, "w") as f:
        f.write(credentials)

    # fetch runtime config and test
    config_dict, errors = config_service.get_runtime_config_and_errors(
        credentials_path, endpoints_path
    )

    assert config_dict
    assert not errors

    assert endpoints == config_dict["endpoints"]
    assert credentials == config_dict["credentials"]


def test_get_runtime_config_errors():
    # pass fake paths that don't point to actual config files
    credentials_path = "/some/fake/path.yml"
    endpoints_path = "/another/fake/path.yml"

    # fetch runtime config and test
    config_dict, errors = config_service.get_runtime_config_and_errors(
        credentials_path, endpoints_path
    )

    # received no config and two value errors
    assert not config_dict
    assert len(errors) == 2
    assert all(isinstance(e, IOError) for e in errors)
